# Generated by Django 5.2 on 2024-09-02 14:25

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("clinicore", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="biosample",
            name="patient",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="biosamples",
                to="clinicore.patient",
            ),
        ),
        migrations.AddField(
            model_name="biosample",
            name="project",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="biosamples",
                to="clinicore.project",
            ),
        ),
        migrations.AddField(
            model_name="biosample",
            name="medications",
            field=models.ManyToManyField(
                related_name="biosamples", to="clinicore.medication"
            ),
        ),
    ]
